#
# spec file for package python-flexx
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-flexx
Version:        0.8.0
Release:        bp155.2.11
Summary:        Python toolkit for creating graphical user interfaces
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/flexxui/flexx
Source:         https://files.pythonhosted.org/packages/source/f/flexx/flexx-%{version}.tar.gz
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module dialite >= 0.5.2}
BuildRequires:  %{python_module imageio}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pscript >= 0.7.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module selenium}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tornado >= 4}
BuildRequires:  %{python_module webruntime >= 0.5.6}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-dialite >= 0.5.2
Requires:       python-pscript >= 0.7.0
Requires:       python-tornado
Requires:       python-webruntime >= 0.5.6
Recommends:     python-imageio
Recommends:     python-numpy
Recommends:     python-vispy
BuildArch:      noarch
%python_subpackages

%description
Flexx is a pure Python toolkit for creating graphical user interfaces
(GUIs), that uses web technology for its rendering. Apps are written
purely in Python; Flexx's transpiler generates the necessary JavaScript
on the fly.

Flexx can be used to create (cross platform) desktop applications, web
applications, and (if designed well) export an app to a standalone HTML
document. It also works in the Jupyter notebook.

%prep
%setup -q -n flexx-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Do not run tests, they require online access to jquery/etc.
#%%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%python3_only %{_bindir}/flexx
%{python_sitelib}/*

%changelog
* Tue May  7 2019 pgajdos@suse.com
- version update to 0.8.0
  * Adds a `PyWidget` class that can be used as a base class for your high-level
    widgets. Because it is a PyComponent, this makes it much easier to write apps
    that fully work in Python (desktop-like apps).
  * The ``FormLayout`` uses CSS ``grid`` instead of ``<table>``.
  * A new ``GridLayout`` widget.
  * A new ``MultiLineEdit`` widget.
  * Improvements to docs and guide.
  * Support for freezing Flexx apps to standalone executables (via PyInstaller).
* Fri Mar 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix the URL
* Tue Mar 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.1:
  * Improved shutdown behavior (#533).
  * Small fix in App.export (#532).
  * Fix bahevior when navigating back to a Flexx app (#536).
  * New examples for Openlayers and including local assets (by @ocobacho).
  * Tests, demos and readme are included in the sdist, helping packaging on Linux (by @toddrme2178).
  * Some performance tweaks which should help in larger applications.
  * Add outernode attribute in TreeItem` widget, enabling more powerful subclasses.
  * The Combobox is smarter about the placement of the "dropdown".
  * A new RangeSlider widget.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Oct 29 2018 Todd R <toddrme2178@gmail.com>
- Update to version 0.6.2
  * Bugfix in combobox.
  * BSDF check dtype in JS.
- Update to version 0.6.0
  * Add ``Widget.minsize_from_children`` property (#497).
  * Update BSDF (data serialization).
  * Widgets van be orphaned upon initialization by setting parent to None (#493)
  * Some internal improvements on the dropdown widget.
- Update to version 0.5.0
  * A major refactoring of the event system.
  * We spun out the PyScript transpiler into the PScript project, as well
    as the webruntime and dialite project. This means that Flexx itself
    is focussed on the GUI aspect alone.
  * Added touch support.
  * Dropped the depency on Phosphor.js.
  * A new combined namespace: ``from flexx import flx``.
  * A proper guide in the docs.
  * More examples.
* Sat Mar  3 2018 jengelh@inai.de
- Summary and description improvements.
* Fri Dec  1 2017 toddrme2178@gmail.com
- intial version
